﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;
using System.Diagnostics;

namespace esl
{
    class FastTrack
    {
        public static PackageId templateId;
        public static string signingUrl;

        public static readonly string TEMPLATE_DESCRIPTION = "This is a package created using the eSignLive SDK";
        public static readonly string TEMPLATE_EMAIL_MESSAGE = "This message should be delivered to all signers";
        public static readonly string TEMPLATE_SIGNER_FIRST = "John";
        public static readonly string TEMPLATE_SIGNER_LAST = "Smith";
        public static readonly string PLACEHOLDER_ID = "PlaceholderId1";

        public static readonly string FAST_TRACK_SIGNER_FIRST = "Patty";
        public static readonly string FAST_TRACK_SIGNER_LAST = "Galant";

        public static readonly string DOCUMENT_NAME = "First Document";
        public static readonly string DOCUMENT_ID = "doc1";

        public static void main()
        {
            EslClient eslClient = new EslClient(Properties.Settings.Default.key, Properties.Settings.Default.url);

            string email1 = "mail33@mailinator.com";
            string PackageName = "StartFastTrackExample Template: " + DateTime.Now;

            FileStream fileStream1 = File.OpenRead(@"C:/Users/hhaidary/Desktop/PDFs/doc1.pdf");

            Signer signer1 = SignerBuilder.NewSignerWithEmail(email1)
                .WithFirstName(TEMPLATE_SIGNER_FIRST)
                .WithLastName(TEMPLATE_SIGNER_LAST).Build();

            Signer signer2 = SignerBuilder.NewSignerPlaceholder(new Placeholder(PLACEHOLDER_ID)).Build();

            DocumentPackage template = PackageBuilder.NewPackageNamed(PackageName)
                .DescribedAs(TEMPLATE_DESCRIPTION)
                    .WithEmailMessage(TEMPLATE_EMAIL_MESSAGE)
                    .WithSigner(signer1)
                    .WithSigner(signer2)
                    .WithDocument(DocumentBuilder.NewDocumentNamed(DOCUMENT_NAME)
                                  .WithId(DOCUMENT_ID)
                                  .FromStream(fileStream1, DocumentType.PDF)
                                  .WithSignature(SignatureBuilder.SignatureFor(email1)
                                   .OnPage(0)
                                   .AtPosition(100, 100))
                                  .WithSignature(SignatureBuilder.SignatureFor(new Placeholder(PLACEHOLDER_ID))
                                   .OnPage(0)
                                   .AtPosition(400, 100))
                                  .Build())
                    .Build();

            templateId = eslClient.CreateTemplate(template);

            FastTrackSigner signer = FastTrackSignerBuilder.NewSignerWithId(signer2.Id)
                    .WithEmail("mail43@mailinator.com")
                    .WithFirstName(FAST_TRACK_SIGNER_FIRST)
                    .WithLastName(FAST_TRACK_SIGNER_LAST)
                    .Build();

            List<FastTrackSigner> signers = new List<FastTrackSigner>();
            signers.Add(signer);
            signingUrl = eslClient.PackageService.StartFastTrack(templateId, signers);

            Debug.WriteLine(signingUrl);
        }
    }
}
